import { useMemo } from 'react';

import { NsTypography } from '@nuskin/foundation-ui-components';

import { BynderImage } from '../../../bynder-image/BynderImage';
import { NsCTALink } from '../../../cta-link';
import useToggleFontColor from '../../../hooks/use-toggle-font-color/useToggleFontColor';
import { HeroBannerProps } from '../../types/types';
import { ContentContainer, ImageContainer, TextContainer } from './HeroBanner.styled';

/**
 * Renders title, description with a background image, and a call to action. This component can render an h1 title.
 */
const HeroBanner = (props: { heroItem: HeroBannerProps }) => {
    const { heroItem } = props;
    const {
        header,
        description,
        textAlignment = 'start',
        fontColor = false,
        image,
        backgroundColor,
        dataTestId = 'hero-banner',
        backgroundScrim,
        renderH1,
        callToAction,
        liveTags,
        $
    } = heroItem;
    const resolvedFontColor = useToggleFontColor(fontColor);

    const backgroundSection = useMemo(
        () => (
            <ImageContainer>
                <BynderImage
                    imageText={image ?? ''}
                    className="hero-banner-image"
                    liveTag={$?.image ?? { 'data-cslp': '' }}
                />
            </ImageContainer>
        ),
        [image, $?.image]
    );
    const textSection = useMemo(
        () => (
            <TextContainer className="hero-text-container" fontColor={resolvedFontColor}>
                <div data-testid="title" {...liveTags?.header}>
                    <NsTypography
                        variant="h2"
                        renderHTMLNode={renderH1}
                        colorOverride={resolvedFontColor}
                        className="title"
                    >
                        {header}
                    </NsTypography>
                </div>
                <div data-testid="description" {...liveTags?.description}>
                    <NsTypography variant="h5" colorOverride={resolvedFontColor} className="description">
                        {description}
                    </NsTypography>
                </div>
                {callToAction?.url ? (
                    <div {...liveTags?.callToAction} data-testid="cta">
                        <NsCTALink
                            ctaProps={{
                                ...callToAction,
                                color: fontColor ? 'secondary' : 'primary'
                            }}
                        />
                    </div>
                ) : null}
            </TextContainer>
        ),
        [
            header,
            description,
            renderH1,
            fontColor,
            resolvedFontColor,
            callToAction,
            liveTags?.header,
            liveTags?.description,
            liveTags?.callToAction
        ]
    );

    const content = useMemo(() => {
        const className = [backgroundScrim ? 'with-scrim' : false, `text-align-${textAlignment}`]
            .filter(Boolean)
            .join(' ');
        return (
            <ContentContainer textAlignment={textAlignment} className={className} backgroundColor={backgroundColor}>
                {backgroundSection}
                {textSection}
            </ContentContainer>
        );
    }, [backgroundColor, backgroundScrim, textAlignment, backgroundSection, textSection]);

    return (
        <section className="hero-banner" data-testid={dataTestId}>
            {content}
        </section>
    );
};

export default HeroBanner;
