import { gql, useQuery } from '@apollo/client';
import {
    formatCurrency,
    getRegionAndLanguageFromQuery
} from '../utils';
import { useRouter } from 'next/router';
import { useMemo } from 'react';



export type ProductsResponseProps = {
    title: string;
    slug: string;
    variants: ProductsResponseVariantProps[];
};

export type ProductsResponseVariantProps = {
    id?: string | null;
    isExclusive?: boolean;
    maxQuantity?: number;
    price?: Price;
    productImages?: ProductImage[];
};

export type ProductImage = {
    alt: string;
    thumbnail?: string;
    url: string;
};

export type Price = {
    currencyCode?: string;
    retail: number;
    retailOriginal?: number | null;
    retailSales?: number;
    retailSubscription?: number;
    wholesale: number;
    wholesaleOriginal?: number;
    wholesaleSales?: number;
    wholesaleSubscription?: number;
};



export const GET_PRODUCTS = gql`
    query ProductsQuery($ids: [String!]!, $market: String, $language: String) {
        productsById(ids: $ids, market: $market, language: $language) {
            products {
                title
                slug
                variants {
                    id
                    maxQuantity
                    isExclusive
                    price {
                        currencyCode
                        retail
                        retailOriginal
                        retailSales
                        retailSubscription
                        wholesale
                        wholesaleOriginal
                        wholesaleSales
                        wholesaleSubscription
                    }
                    productImages {
                        thumbnail
                        alt
                        url
                    }
                }
            }
        }
    }
`;

const useProducts = (props: {sku?: string[], addToCartButtonText?: string, isRetail?: boolean }) => {
    const { sku, addToCartButtonText, isRetail } = props;
    const router = useRouter();
    const { region, language } = getRegionAndLanguageFromQuery(router.query) || {};

    const variables = useMemo(() => {
        return {
            ids: sku,
            market: region?.toUpperCase(),
            language: language
        };
    }, [language, region, sku]);

    const { loading, error, data } = useQuery(GET_PRODUCTS, {
        variables
    });

    const getSingleProductVariants = (products: ProductsResponseProps[]) => {
        return products?.filter(({ variants }: ProductsResponseProps) => {
            const { maxQuantity, isExclusive } = variants?.[0] || {};
            return variants?.length < 2 && maxQuantity !== 0 && !isExclusive;
        });
    };

    const products = getSingleProductVariants(data?.productsById?.products);

    const formatedProducts = products?.map((obj: ProductsResponseProps) => {
        return {
            ...obj,
            addToCartButtonText: addToCartButtonText,
            variants:
                obj?.variants?.map((items: ProductsResponseVariantProps) => {
                    const { retail, wholesale, currencyCode } = items?.price || {};
                    const currency = isRetail ? retail : wholesale;
                    const locale = `${language}_${region?.toUpperCase()}`;
                    return {
                        ...items,
                        price: {
                            ...items?.price,
                            productPrice: formatCurrency(currency, currencyCode, locale)
                        },
                        slug: obj?.slug,
                        productImages: items.productImages?.[0] || {}
                    };
                })[0] || {}
        };
    });
    return { loading, error, data: formatedProducts };
};

export default useProducts;
